@@ -1,7 +1,11 @@
 #include "puntatemain.h"
 #include "ui_puntatemain.h"
+#include "config.h"
 
 #include <QProcess>
+#include <QDesktopServices>
+#include <QFileDialog>
+#include <QDialog>
 
 PuntateMain::PuntateMain(QWidget *parent) :
     QMainWindow(parent),
@@ -202,9 +206,12 @@ void PuntateMain::on_stream13_clicked()
 
 void PuntateMain::on_actionPuntate_Scaricate_triggered()
 {
-    QProcess process;
-    process.start("sh /opt/serviziopubblico/script/puntate.sh");
-    process.waitForFinished();
+    QString fileName = QFileDialog::getOpenFileName(this,
+         tr("Locate Download Show"),
+         USER_DIR,
+         tr("Show (*.mp4)"));
+    if (!fileName.isEmpty())
+        return;
 }
 
 void PuntateMain::on_down13_2_clicked()
